==> ocsp-server-3.0.0-sources.jar: org/xipki/ocsp/server/impl/jaxb/StoreType.java <==

package org.xipki.ocsp.server.impl.jaxb;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for storeType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="storeType"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;all&gt;
 *         &lt;element name="source"&gt;
 *           &lt;complexType&gt;
 *             &lt;complexContent&gt;
 *               &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *                 &lt;all&gt;
 *                   &lt;element name="type" type="{http://www.w3.org/2001/XMLSchema}string"/&gt;
 *                   &lt;element name="datasource" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/&gt;
 *                   &lt;element name="conf" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/&gt;
 *                 &lt;/all&gt;
 *               &lt;/restriction&gt;
 *             &lt;/complexContent&gt;
 *           &lt;/complexType&gt;
 *         &lt;/element&gt;
 *         &lt;element name="ignoreExpiredCert" type="{http://www.w3.org/2001/XMLSchema}boolean" minOccurs="0"/&gt;
 *         &lt;element name="ignoreNotYetValidCert" type="{http://www.w3.org/2001/XMLSchema}boolean" minOccurs="0"/&gt;
 *         &lt;element name="retentionInterval" type="{http://www.w3.org/2001/XMLSchema}int" minOccurs="0"/&gt;
 *         &lt;element name="unknownSerialAsGood" type="{http://www.w3.org/2001/XMLSchema}boolean" minOccurs="0"/&gt;
 *         &lt;element name="includeArchiveCutoff" type="{http://www.w3.org/2001/XMLSchema}boolean" minOccurs="0"/&gt;
 *         &lt;element name="includeCrlID" type="{http://www.w3.org/2001/XMLSchema}boolean" minOccurs="0"/&gt;
 *       &lt;/all&gt;
 *       &lt;attribute name="name" use="required" type="{http://www.w3.org/2001/XMLSchema}string" /&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "storeType", propOrder = {

})
public class StoreType {

    @XmlElement(required = true)
    protected StoreType.Source source;
    protected Boolean ignoreExpiredCert;
    protected Boolean ignoreNotYetValidCert;
    protected Integer retentionInterval;
    protected Boolean unknownSerialAsGood;
    protected Boolean includeArchiveCutoff;
    protected Boolean includeCrlID;
    @XmlAttribute(name = "name", required = true)
    protected String name;

    /**
     * Gets the value of the source property.
     * 
     * @return
     *     possible object is
     *     {@link StoreType.Source }
     *     
     */
    public StoreType.Source getSource() {
        return source;
    }

    /**
     * Sets the value of the source property.
     * 
     * @param value
     *     allowed object is
     *     {@link StoreType.Source }
     *     
     */
    public void setSource(StoreType.Source value) {
        this.source = value;
    }

    /**
     * Gets the value of the ignoreExpiredCert property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public Boolean isIgnoreExpiredCert() {
        return ignoreExpiredCert;
    }

    /**
     * Sets the value of the ignoreExpiredCert property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setIgnoreExpiredCert(Boolean value) {
        this.ignoreExpiredCert = value;
    }

    /**
     * Gets the value of the ignoreNotYetValidCert property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public Boolean isIgnoreNotYetValidCert() {
        return ignoreNotYetValidCert;
    }

    /**
     * Sets the value of the ignoreNotYetValidCert property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setIgnoreNotYetValidCert(Boolean value) {
        this.ignoreNotYetValidCert = value;
    }

    /**
     * Gets the value of the retentionInterval property.
     * 
     * @return
     *     possible object is
     *     {@link Integer }
     *     
     */
    public Integer getRetentionInterval() {
        return retentionInterval;
    }

    /**
     * Sets the value of the retentionInterval property.
     * 
     * @param value
     *     allowed object is
     *     {@link Integer }
     *     
     */
    public void setRetentionInterval(Integer value) {
        this.retentionInterval = value;
    }

    /**
     * Gets the value of the unknownSerialAsGood property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public Boolean isUnknownSerialAsGood() {
        return unknownSerialAsGood;
    }

    /**
     * Sets the value of the unknownSerialAsGood property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setUnknownSerialAsGood(Boolean value) {
        this.unknownSerialAsGood = value;
    }

    /**
     * Gets the value of the includeArchiveCutoff property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public Boolean isIncludeArchiveCutoff() {
        return includeArchiveCutoff;
    }

    /**
     * Sets the value of the includeArchiveCutoff property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setIncludeArchiveCutoff(Boolean value) {
        this.includeArchiveCutoff = value;
    }

    /**
     * Gets the value of the includeCrlID property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public Boolean isIncludeCrlID() {
        return includeCrlID;
    }

    /**
     * Sets the value of the includeCrlID property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setIncludeCrlID(Boolean value) {
        this.includeCrlID = value;
    }

    /**
     * Gets the value of the name property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getName() {
        return name;
    }

    /**
     * Sets the value of the name property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setName(String value) {
        this.name = value;
    }


    /**
     * <p>Java class for anonymous complex type.
     * 
     * <p>The following schema fragment specifies the expected content contained within this class.
     * 
     * <pre>
     * &lt;complexType&gt;
     *   &lt;complexContent&gt;
     *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
     *       &lt;all&gt;
     *         &lt;element name="type" type="{http://www.w3.org/2001/XMLSchema}string"/&gt;
     *         &lt;element name="datasource" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/&gt;
     *         &lt;element name="conf" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/&gt;
     *       &lt;/all&gt;
     *     &lt;/restriction&gt;
     *   &lt;/complexContent&gt;
     * &lt;/complexType&gt;
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "", propOrder = {

    })
    public static class Source {

        @XmlElement(required = true)
        protected String type;
        protected String datasource;
        protected String conf;

        /**
         * Gets the value of the type property.
         * 
         * @return
         *     possible object is
         *     {@link String }
         *     
         */
        public String getType() {
            return type;
        }

        /**
         * Sets the value of the type property.
         * 
         * @param value
         *     allowed object is
         *     {@link String }
         *     
         */
        public void setType(String value) {
            this.type = value;
        }

        /**
         * Gets the value of the datasource property.
         * 
         * @return
         *     possible object is
         *     {@link String }
         *     
         */
        public String getDatasource() {
            return datasource;
        }

        /**
         * Sets the value of the datasource property.
         * 
         * @param value
         *     allowed object is
         *     {@link String }
         *     
         */
        public void setDatasource(String value) {
            this.datasource = value;
        }

        /**
         * Gets the value of the conf property.
         * 
         * @return
         *     possible object is
         *     {@link String }
         *     
         */
        public String getConf() {
            return conf;
        }

        /**
         * Sets the value of the conf property.
         * 
         * @param value
         *     allowed object is
         *     {@link String }
         *     
         */
        public void setConf(String value) {
            this.conf = value;
        }

    }

}

==> ocsp-server-4.0.0-sources.jar: org/xipki/ocsp/server/impl/jaxb/StoreType.java <==

package org.xipki.ocsp.server.impl.jaxb;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for storeType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="storeType"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;all&gt;
 *         &lt;element name="source"&gt;
 *           &lt;complexType&gt;
 *             &lt;complexContent&gt;
 *               &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *                 &lt;all&gt;
 *                   &lt;element name="type" type="{http://www.w3.org/2001/XMLSchema}string"/&gt;
 *                   &lt;element name="datasource" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/&gt;
 *                   &lt;element name="conf" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/&gt;
 *                 &lt;/all&gt;
 *               &lt;/restriction&gt;
 *             &lt;/complexContent&gt;
 *           &lt;/complexType&gt;
 *         &lt;/element&gt;
 *         &lt;element name="ignoreExpiredCert" type="{http://www.w3.org/2001/XMLSchema}boolean" minOccurs="0"/&gt;
 *         &lt;element name="ignoreNotYetValidCert" type="{http://www.w3.org/2001/XMLSchema}boolean" minOccurs="0"/&gt;
 *         &lt;element name="retentionInterval" type="{http://www.w3.org/2001/XMLSchema}int" minOccurs="0"/&gt;
 *         &lt;element name="unknownSerialAsGood" type="{http://www.w3.org/2001/XMLSchema}boolean" minOccurs="0"/&gt;
 *         &lt;element name="includeArchiveCutoff" type="{http://www.w3.org/2001/XMLSchema}boolean" minOccurs="0"/&gt;
 *         &lt;element name="includeCrlId" type="{http://www.w3.org/2001/XMLSchema}boolean" minOccurs="0"/&gt;
 *       &lt;/all&gt;
 *       &lt;attribute name="name" use="required" type="{http://www.w3.org/2001/XMLSchema}string" /&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "storeType", propOrder = {

})
public class StoreType {

    @XmlElement(required = true)
    protected StoreType.Source source;
    protected Boolean ignoreExpiredCert;
    protected Boolean ignoreNotYetValidCert;
    protected Integer retentionInterval;
    protected Boolean unknownSerialAsGood;
    protected Boolean includeArchiveCutoff;
    protected Boolean includeCrlId;
    @XmlAttribute(name = "name", required = true)
    protected String name;

    /**
     * Gets the value of the source property.
     * 
     * @return
     *     possible object is
     *     {@link StoreType.Source }
     *     
     */
    public StoreType.Source getSource() {
        return source;
    }

    /**
     * Sets the value of the source property.
     * 
     * @param value
     *     allowed object is
     *     {@link StoreType.Source }
     *     
     */
    public void setSource(StoreType.Source value) {
        this.source = value;
    }

    /**
     * Gets the value of the ignoreExpiredCert property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public Boolean isIgnoreExpiredCert() {
        return ignoreExpiredCert;
    }

    /**
     * Sets the value of the ignoreExpiredCert property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setIgnoreExpiredCert(Boolean value) {
        this.ignoreExpiredCert = value;
    }

    /**
     * Gets the value of the ignoreNotYetValidCert property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public Boolean isIgnoreNotYetValidCert() {
        return ignoreNotYetValidCert;
    }

    /**
     * Sets the value of the ignoreNotYetValidCert property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setIgnoreNotYetValidCert(Boolean value) {
        this.ignoreNotYetValidCert = value;
    }

    /**
     * Gets the value of the retentionInterval property.
     * 
     * @return
     *     possible object is
     *     {@link Integer }
     *     
     */
    public Integer getRetentionInterval() {
        return retentionInterval;
    }

    /**
     * Sets the value of the retentionInterval property.
     * 
     * @param value
     *     allowed object is
     *     {@link Integer }
     *     
     */
    public void setRetentionInterval(Integer value) {
        this.retentionInterval = value;
    }

    /**
     * Gets the value of the unknownSerialAsGood property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public Boolean isUnknownSerialAsGood() {
        return unknownSerialAsGood;
    }

    /**
     * Sets the value of the unknownSerialAsGood property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setUnknownSerialAsGood(Boolean value) {
        this.unknownSerialAsGood = value;
    }

    /**
     * Gets the value of the includeArchiveCutoff property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public Boolean isIncludeArchiveCutoff() {
        return includeArchiveCutoff;
    }

    /**
     * Sets the value of the includeArchiveCutoff property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setIncludeArchiveCutoff(Boolean value) {
        this.includeArchiveCutoff = value;
    }

    /**
     * Gets the value of the includeCrlId property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public Boolean isIncludeCrlId() {
        return includeCrlId;
    }

    /**
     * Sets the value of the includeCrlId property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setIncludeCrlId(Boolean value) {
        this.includeCrlId = value;
    }

    /**
     * Gets the value of the name property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getName() {
        return name;
    }

    /**
     * Sets the value of the name property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setName(String value) {
        this.name = value;
    }


    /**
     * <p>Java class for anonymous complex type.
     * 
     * <p>The following schema fragment specifies the expected content contained within this class.
     * 
     * <pre>
     * &lt;complexType&gt;
     *   &lt;complexContent&gt;
     *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
     *       &lt;all&gt;
     *         &lt;element name="type" type="{http://www.w3.org/2001/XMLSchema}string"/&gt;
     *         &lt;element name="datasource" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/&gt;
     *         &lt;element name="conf" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/&gt;
     *       &lt;/all&gt;
     *     &lt;/restriction&gt;
     *   &lt;/complexContent&gt;
     * &lt;/complexType&gt;
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "", propOrder = {

    })
    public static class Source {

        @XmlElement(required = true)
        protected String type;
        protected String datasource;
        protected String conf;

        /**
         * Gets the value of the type property.
         * 
         * @return
         *     possible object is
         *     {@link String }
         *     
         */
        public String getType() {
            return type;
        }

        /**
         * Sets the value of the type property.
         * 
         * @param value
         *     allowed object is
         *     {@link String }
         *     
         */
        public void setType(String value) {
            this.type = value;
        }

        /**
         * Gets the value of the datasource property.
         * 
         * @return
         *     possible object is
         *     {@link String }
         *     
         */
        public String getDatasource() {
            return datasource;
        }

        /**
         * Sets the value of the datasource property.
         * 
         * @param value
         *     allowed object is
         *     {@link String }
         *     
         */
        public void setDatasource(String value) {
            this.datasource = value;
        }

        /**
         * Gets the value of the conf property.
         * 
         * @return
         *     possible object is
         *     {@link String }
         *     
         */
        public String getConf() {
            return conf;
        }

        /**
         * Sets the value of the conf property.
         * 
         * @param value
         *     allowed object is
         *     {@link String }
         *     
         */
        public void setConf(String value) {
            this.conf = value;
        }

    }

}
